@@ -79,7 +79,7 @@ def state_value(state, address, init = 0, end = 15):
 def bit_value(state, address, bit):
     #return state_value(state, address, bit, bit)
     temp = format(state[address], '016b')
-    return temp[len(temp)-1-bit]
+    return int(temp[len(temp)-1-bit])
 
 def change_bit_value(state, address, bit, value):
     if value:
